@@ -85,7 +85,7 @@ def _set_boot_device(task, system, device, persistent=False):
             use_new_set_system_boot = False
             system.set_system_boot_source(device, enabled=enabled)
     except sushy.exceptions.SushyError as e:
-        if desired_enabled == sushy.BOOT_SOURCE_ENABLED_CONTINUOUS:
+        if enabled == sushy.BOOT_SOURCE_ENABLED_CONTINUOUS:
             # NOTE(dtantsur): continuous boot device settings have been
             # removed from Redfish, and some vendors stopped supporting
             # it before an alternative was provided. As a work around,
