@@ -12,11 +12,13 @@
 #    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 #    License for the specific language governing permissions and limitations
 #    under the License.
-
+from oslo_config import cfg
+from oslo_log import log
 from oslo_utils import strutils
 from oslo_utils import uuidutils
 from oslo_utils import versionutils
 from oslo_versionedobjects import base as object_base
+import six
 
 from ironic.common import exception
 from ironic.common.i18n import _
@@ -29,6 +31,9 @@ from ironic.objects import notification
 
 REQUIRED_INT_PROPERTIES = ['local_gb', 'cpus', 'memory_mb']
 
+CONF = cfg.CONF
+LOG = log.getLogger(__name__)
+
 
 @base.IronicObjectRegistry.register
 class Node(base.IronicObject, object_base.VersionedObjectDictCompat):
@@ -66,7 +71,10 @@ class Node(base.IronicObject, object_base.VersionedObjectDictCompat):
     # Version 1.27: Add conductor_group field
     # Version 1.28: Add automated_clean field
     # Version 1.29: Add protected and protected_reason fields
-    VERSION = '1.29'
+    # Version 1.30: Add owner field
+    # Version 1.31: Add allocation_id field
+    # Version 1.32: Add description field
+    VERSION = '1.32'
 
     dbapi = db_api.get_instance()
 
@@ -135,6 +143,7 @@ class Node(base.IronicObject, object_base.VersionedObjectDictCompat):
         'automated_clean': objects.fields.BooleanField(nullable=True),
         'protected': objects.fields.BooleanField(),
         'protected_reason': object_fields.StringField(nullable=True),
+        'allocation_id': object_fields.IntegerField(nullable=True),
 
         'bios_interface': object_fields.StringField(nullable=True),
         'boot_interface': object_fields.StringField(nullable=True),
@@ -149,6 +158,8 @@ class Node(base.IronicObject, object_base.VersionedObjectDictCompat):
         'storage_interface': object_fields.StringField(nullable=True),
         'vendor_interface': object_fields.StringField(nullable=True),
         'traits': object_fields.ObjectField('TraitList', nullable=True),
+        'owner': object_fields.StringField(nullable=True),
+        'description': object_fields.StringField(nullable=True),
     }
 
     def as_dict(self, secure=False):
@@ -410,6 +421,16 @@ class Node(base.IronicObject, object_base.VersionedObjectDictCompat):
                         object, e.g.: Node(context)
         :raises: InvalidParameterValue if some property values are invalid.
         """
+
+        for attr_name in ('last_error', 'maintenance_reason'):
+            attr_value = getattr(self, attr_name, '')
+            if (attr_value and isinstance(attr_value, six.string_types) and
+                    len(attr_value) > CONF.log_in_db_max_size):
+                LOG.info('Truncating too long %s to %s characters for node %s',
+                         attr_name, CONF.log_in_db_max_size, self.uuid)
+                setattr(self, attr_name,
+                        attr_value[0:CONF.log_in_db_max_size])
+
         updates = self.do_version_changes_for_db()
         self._validate_property_values(updates.get('properties'))
         if 'driver' in updates and 'driver_internal_info' not in updates:
@@ -493,18 +514,6 @@ class Node(base.IronicObject, object_base.VersionedObjectDictCompat):
         node = cls._from_db_object(context, cls(), db_node)
         return node
 
-    def _convert_fault_field(self, target_version,
-                             remove_unavailable_fields=True):
-        fault_is_set = self.obj_attr_is_set('fault')
-        if target_version >= (1, 25):
-            if not fault_is_set:
-                self.fault = None
-        elif fault_is_set:
-            if remove_unavailable_fields:
-                delattr(self, 'fault')
-            elif self.fault is not None:
-                self.fault = None
-
     def _convert_deploy_step_field(self, target_version,
                                    remove_unavailable_fields=True):
         # NOTE(rloo): Typically we set the value to None. However,
@@ -581,6 +590,12 @@ class Node(base.IronicObject, object_base.VersionedObjectDictCompat):
             should be set to None (or removed).
         Version 1.29: protected was added. For versions prior to this, it
             should be set to False (or removed).
+        Version 1.30: owner was added. For versions prior to this, it should be
+            set to None or removed.
+        Version 1.31: allocation_id was added. For versions prior to this, it
+            should be set to None (or removed).
+        Version 1.32: description was added. For versions prior to this, it
+            should be set to None (or removed).
 
         :param target_version: the desired version of the object
         :param remove_unavailable_fields: True to remove fields that are
@@ -592,8 +607,9 @@ class Node(base.IronicObject, object_base.VersionedObjectDictCompat):
 
         # Convert the different fields depending on version
         fields = [('rescue_interface', 22), ('traits', 23),
-                  ('bios_interface', 24), ('automated_clean', 28),
-                  ('protected_reason', 29)]
+                  ('bios_interface', 24), ('fault', 25),
+                  ('automated_clean', 28), ('protected_reason', 29),
+                  ('owner', 30), ('allocation_id', 31), ('description', 32)]
         for name, minor in fields:
             self._adjust_field_to_version(name, None, target_version,
                                           1, minor, remove_unavailable_fields)
@@ -602,7 +618,6 @@ class Node(base.IronicObject, object_base.VersionedObjectDictCompat):
         self._adjust_field_to_version('protected', False, target_version,
                                       1, 29, remove_unavailable_fields)
 
-        self._convert_fault_field(target_version, remove_unavailable_fields)
         self._convert_deploy_step_field(target_version,
                                         remove_unavailable_fields)
         self._convert_conductor_group_field(target_version,
@@ -626,6 +641,7 @@ class NodePayload(notification.NotificationPayloadBase):
         'console_enabled': ('node', 'console_enabled'),
         'created_at': ('node', 'created_at'),
         'deploy_step': ('node', 'deploy_step'),
+        'description': ('node', 'description'),
         'driver': ('node', 'driver'),
         'extra': ('node', 'extra'),
         'inspection_finished_at': ('node', 'inspection_finished_at'),
@@ -648,6 +664,7 @@ class NodePayload(notification.NotificationPayloadBase):
         'rescue_interface': ('node', 'rescue_interface'),
         'storage_interface': ('node', 'storage_interface'),
         'vendor_interface': ('node', 'vendor_interface'),
+        'owner': ('node', 'owner'),
         'power_state': ('node', 'power_state'),
         'properties': ('node', 'properties'),
         'protected': ('node', 'protected'),
@@ -674,13 +691,16 @@ class NodePayload(notification.NotificationPayloadBase):
     # Version 1.9: Add deploy_step field exposed via API.
     # Version 1.10: Add conductor_group field exposed via API.
     # Version 1.11: Add protected and protected_reason fields exposed via API.
-    VERSION = '1.11'
+    # Version 1.12: Add node owner field.
+    # Version 1.13: Add description field.
+    VERSION = '1.13'
     fields = {
         'clean_step': object_fields.FlexibleDictField(nullable=True),
         'conductor_group': object_fields.StringField(nullable=True),
         'console_enabled': object_fields.BooleanField(nullable=True),
         'created_at': object_fields.DateTimeField(nullable=True),
         'deploy_step': object_fields.FlexibleDictField(nullable=True),
+        'description': object_fields.StringField(nullable=True),
         'driver': object_fields.StringField(nullable=True),
         'extra': object_fields.FlexibleDictField(nullable=True),
         'inspection_finished_at': object_fields.DateTimeField(nullable=True),
@@ -703,6 +723,7 @@ class NodePayload(notification.NotificationPayloadBase):
         'storage_interface': object_fields.StringField(nullable=True),
         'vendor_interface': object_fields.StringField(nullable=True),
         'name': object_fields.StringField(nullable=True),
+        'owner': object_fields.StringField(nullable=True),
         'power_state': object_fields.StringField(nullable=True),
         'properties': object_fields.FlexibleDictField(nullable=True),
         'protected': object_fields.BooleanField(nullable=True),
@@ -754,7 +775,9 @@ class NodeSetPowerStatePayload(NodePayload):
     # Version 1.9: Parent NodePayload version 1.9
     # Version 1.10: Parent NodePayload version 1.10
     # Version 1.11: Parent NodePayload version 1.11
-    VERSION = '1.11'
+    # Version 1.12: Parent NodePayload version 1.12
+    # Version 1.13: Parent NodePayload version 1.13
+    VERSION = '1.13'
 
     fields = {
         # "to_power" indicates the future target_power_state of the node. A
@@ -806,7 +829,9 @@ class NodeCorrectedPowerStatePayload(NodePayload):
     # Version 1.9: Parent NodePayload version 1.9
     # Version 1.10: Parent NodePayload version 1.10
     # Version 1.11: Parent NodePayload version 1.11
-    VERSION = '1.11'
+    # Version 1.12: Parent NodePayload version 1.12
+    # Version 1.13: Parent NodePayload version 1.13
+    VERSION = '1.13'
 
     fields = {
         'from_power': object_fields.StringField(nullable=True)
@@ -842,7 +867,9 @@ class NodeSetProvisionStatePayload(NodePayload):
     # Version 1.9: Parent NodePayload version 1.9
     # Version 1.10: Parent NodePayload version 1.10
     # Version 1.11: Parent NodePayload version 1.11
-    VERSION = '1.11'
+    # Version 1.12: Parent NodePayload version 1.12
+    # Version 1.13: Parent NodePayload version 1.13
+    VERSION = '1.13'
 
     SCHEMA = dict(NodePayload.SCHEMA,
                   **{'instance_info': ('node', 'instance_info')})
@@ -885,7 +912,9 @@ class NodeCRUDPayload(NodePayload):
     # Version 1.7: Parent NodePayload version 1.9
     # Version 1.8: Parent NodePayload version 1.10
     # Version 1.9: Parent NodePayload version 1.11
-    VERSION = '1.9'
+    # Version 1.10: Parent NodePayload version 1.12
+    # Version 1.11: Parent NodePayload version 1.13
+    VERSION = '1.11'
 
     SCHEMA = dict(NodePayload.SCHEMA,
                   **{'instance_info': ('node', 'instance_info'),
