@@ -589,8 +589,10 @@ class iPXEBootTestCase(db_base.DbTestCase):
                           ramdisk_label: ['', '/path/to/' + ramdisk_label]}
             get_image_info_mock.return_value = image_info
             task.driver.boot.clean_up_ramdisk(task)
-            clean_up_pxe_env_mock.assert_called_once_with(task, image_info)
-            get_image_info_mock.assert_called_once_with(task.node, mode=mode)
+            clean_up_pxe_env_mock.assert_called_once_with(
+                task, image_info, ipxe_enabled=True)
+            get_image_info_mock.assert_called_once_with(
+                task.node, mode=mode, ipxe_enabled=True)
 
     def test_clean_up_ramdisk(self):
         self.node.provision_state = states.DEPLOYING
@@ -620,7 +622,7 @@ class iPXEBootTestCase(db_base.DbTestCase):
             dhcp_opts = pxe_utils.dhcp_options_for_instance(
                 task, ipxe_enabled=True)
             pxe_config_path = pxe_utils.get_pxe_config_file_path(
-                task.node.uuid)
+                task.node.uuid, ipxe_enabled=True)
             task.node.properties['capabilities'] = 'boot_mode:bios'
             task.node.driver_internal_info['root_uuid_or_disk_id'] = (
                 "30212642-09d3-467f-8e09-21685826ab50")
@@ -662,7 +664,7 @@ class iPXEBootTestCase(db_base.DbTestCase):
             dhcp_opts = pxe_utils.dhcp_options_for_instance(
                 task, ipxe_enabled=True)
             pxe_config_path = pxe_utils.get_pxe_config_file_path(
-                task.node.uuid)
+                task.node.uuid, ipxe_enabled=True)
             task.node.properties['capabilities'] = 'boot_mode:bios'
             task.node.driver_internal_info['root_uuid_or_disk_id'] = (
                 "30212642-09d3-467f-8e09-21685826ab50")
@@ -777,7 +779,7 @@ class iPXEBootTestCase(db_base.DbTestCase):
             dhcp_opts = pxe_utils.dhcp_options_for_instance(task,
                                                             ipxe_enabled=True)
             pxe_config_path = pxe_utils.get_pxe_config_file_path(
-                task.node.uuid)
+                task.node.uuid, ipxe_enabled=True)
             task.node.properties['capabilities'] = 'boot_mode:bios'
             task.driver.boot.prepare_instance(task)
             self.assertFalse(get_image_info_mock.called)
@@ -834,7 +836,8 @@ class iPXEBootTestCase(db_base.DbTestCase):
                           'ramdisk': ['', '/path/to/ramdisk']}
             get_image_info_mock.return_value = image_info
             task.driver.boot.clean_up_instance(task)
-            clean_up_pxe_env_mock.assert_called_once_with(task, image_info)
+            clean_up_pxe_env_mock.assert_called_once_with(
+                task, image_info, ipxe_enabled=True)
             get_image_info_mock.assert_called_once_with(
                 task, ipxe_enabled=True)
 
