@@ -31,7 +31,8 @@ DRACCLIENT_CONSTANTS_MOD_SPEC = (
     'POWER_OFF',
     'POWER_ON',
     'REBOOT',
-    'RebootRequired'
+    'RebootRequired',
+    'RaidStatus'
 )
 
 DRACCLIENT_CONSTANTS_REBOOT_REQUIRED_MOD_SPEC = (
@@ -40,6 +41,10 @@ DRACCLIENT_CONSTANTS_REBOOT_REQUIRED_MOD_SPEC = (
     'false'
 )
 
+DRACCLIENT_CONSTANTS_RAID_STATUS_MOD_SPEC = (
+    'jbod',
+    'raid'
+)
 
 # proliantutils
 PROLIANTUTILS_SPEC = (
